import { Component, OnInit, TemplateRef, ViewChild } from "@angular/core";
import { FormBuilder, Validators, FormGroup} from '@angular/forms';
import { CustomValidators } from 'ng2-validation';
import { BsModalService } from "ngx-bootstrap/modal";
import { FlexTableComponent } from "../../../../../shared/common/FlexTable.component";
import { AppComponent } from "../../../../../app.component";
import {FrameUploaderComponent} from '../../../../../core/uploader/uploader.component';
import { FrameRequest } from "../../../../../shared/frame/frame-request";
import { FramePagerComponent } from "../../../../../core/pager/pager.component";
import { FrameFunction } from "../../../../../shared/frame/frame_function";
import { ThemesService } from "../../../../../core/themes/themes.service";

@Component({
  selector: "app-pl-shoolquery",
  templateUrl: "./school-query.component.html",
  styleUrls: ["./school-query.component.scss"]
})
export class ShoolQueryComponent extends FlexTableComponent implements OnInit {

  @ViewChild('uploader')
  uploader: FrameUploaderComponent;
  @ViewChild('framePager')
  framePager:FramePagerComponent;
  @ViewChild('oldCjPager')
  oldCjPager:FramePagerComponent;
  @ViewChild('ticketAssoPager')
  ticketAssoPager:FramePagerComponent;

  courseList=[];
  //TODO
  QUERY_URL = "by/byApply/queryPage.htm";
  DELETE_URL = "by/byApply/delete.htm";
  GET_URL = "by/byApply/get.htm";
  ADD_URL = "by/byApply/add.htm";
  EDIT_URL = "by/byApply/edit.htm";

  ORG_LIST_URL = "cf/cfOrganization/list.htm";
  AUTH_DETAIL_URL = "by/byApply/getdetail.htm";
  AUTH_LIST_URL = "by/byApply/viewauth.htm";//审核记录
  OLD_CJ_URL = "hz/cjJigechengjiOld/page.htm";
  UPLOAD_URL = "pl/byApply/upload.htm";
  TICKET_ASSO_SCORE_URL = "kj/kjUnifiedScoreDetail/ticketassopage.htm";//准考证关联成绩查询

  orgList = [];
  authList = [];
  filePath : String;
  radioSelect : any;
  scoreList = [];//考生的毕业成绩Map
  replScoreList = [];//用来顶替的成绩列表
  majorList = [];
  masterSchoolList = [];
  jionSchoolList = [];

  //毕业录入成绩
  inputScore = {
    use_type: "",
    by_apply_id: "",
    std_reg_id: "",
    major_id: "",
    major_code: "",
    course_code: "",//新录入的课程代码
    course_name: "",//新录入的课程名称
    origin_score: "",
    final_score: "",
    score_nature: "",
    score_source: "",
    score_id: "",
    old_course_id: "",//之前成绩对应的课程ID
  };

  inputModalWin: any;
  courseReplWin: any;
  turnInAssocitWin : any;//转入关联
  ticketNoAssocitWin : any;//准考证关联
  oldCjWin: any;
  stdRefWin: any;

  turnInScoreList = [];//转入成绩
  turnInScore : any;//转入成绩对象

  repl_course_id : any;//待顶替课程id
  repl_score_id: any;//待顶替的成绩id
  public scoreFormModel: FormGroup;

  majorLevel = "";

  showTicketPage=false;//默认不显示

  photo_url: any;

  private applyStatus = {
    NEW_0: 0,
    TO_FIRST_AUDIT_1: 1,
    TO_FINAL_AUDIT_2: 2,
    TO_DISTRIBUTE_3: 3,
    ARCHIVED_4: 4
  };

  constructor(
    public bsModalService: BsModalService,
    fb: FormBuilder
  ) {
    super();
    this.formModel = fb.group({
      id: [null],
      'std_name' : [null],
      'cert_no': [null],
      'ticket_no': [null],
      'std_sex': [null],
      'nation': [null],
      'std_birth': [null],
      'native_prov': [null],
      'native_city': [null],
      'political': [null],
      'pre_edu': [null],
      'work_unit': [null],
      'telephone': [null],
      'address': [null],
      'post_code': [null],
      'radioSelect' : [null, Validators.compose([Validators.required])],
      'remark' : [null, Validators.compose([Validators.required])],
    });
    this.scoreFormModel = fb.group({
      id: [null],
      'course_code' : [null, Validators.compose([Validators.required])],
      'course_name' : [null, Validators.compose([Validators.required])],
      'final_score' : [null, Validators.compose([Validators.required])],
    });
  }

  ngOnInit() {
     //课程
     FrameRequest.requestArray("pl/plCourse/listCourseByType.htm", {course_exam_type:"",special_flag:""}, (arrary)=>{
      this.courseList = arrary;
    });

    FrameRequest.requestMap("by/byApply/initdata.htm", {}, async (map)=>{
      this.majorList  = map.majorList;//专业
      this.orgList = map.cityOrgList;//市考办
      this.masterSchoolList = map.schoolOrgList;//主考学校
      this.jionSchoolList = map.jionSchoolOrgList;//衔接学校
      this.query.examTimeId = map.examTimeId;
			this.photo_url = map.photo_url;
      this.framePager.reload();
    });
  }

  public query = {
    query: "",
    cityOrgId: "",
    masterSchoolId: "",
    jionSchoolId: "",
    examTimeId: "",
    majorId: "",
    status: "",
    std_source:""
  };

  public oldCjQuery = {
    query: ""
  }
  public turnInQuery = {
    oldCourseId: "",
    stdName: "",
    ticketNo: "",
    courseCode: ""
  }
  public ticketAssoQuery = {
    ticketNo: "",
  }
  public stdRefQuery = {
    certNo: "",
    ticketNo: "",
    majorId: "", //待毕业专业
    masterSchoolId: "",
    jionSchoolId:""
  }

  search(param) {
    param.query = this.query.query;
   
    if (!this.query.std_source) {
      this.query.std_source = "";
    }
    if (!this.query.cityOrgId) {
      this.query.cityOrgId = "";
    }
    if (!this.query.majorId) {
      this.query.majorId = "";
    }
    if (!this.query.masterSchoolId) {
      this.query.masterSchoolId = "";
    }
    if (!this.query.jionSchoolId) {
      this.query.jionSchoolId = "";
    }
    if (!this.query.examTimeId) {
      this.query.examTimeId = "";
    }
    if (!this.query.status) {
      this.query.status="";
    }
    param.city_org_id = this.query.cityOrgId;
    param.major_id = this.query.majorId;
    param.school_id = this.query.masterSchoolId;
    param.jion_school_id = this.query.jionSchoolId;
    param.exam_time_id = this.query.examTimeId;
    param.by_status = this.query.status;
    param.std_source = this.query.std_source;
  }

  replScoreSearch(param) {
      param.stdRegId=this.item.std_id;
      param.majorId=this.item.major_id;
      param.courseId=this.repl_course_id;
  }

  oldCjSearch(param) {
    param.query = this.oldCjQuery.query;
  }
  //准考证关联
  ticketAssoSearch(param) {
    param.ticketNo = this.ticketAssoQuery.ticketNo;
  }
  //转入
  turnInSearch(param) {
    param.std_name = this.turnInQuery.stdName;
    param.ticket_no = this.turnInQuery.ticketNo;
    param.course_code = this.turnInQuery.courseCode;
  }

  //弹出审核框
  showEditWin(obj) {
   
   
    this.editShowType="only";
    FrameRequest.requestMap(this.AUTH_DETAIL_URL, {id: obj.id}, (map) => {
      this.item = map.detail;
      this.majorLevel = map.majorLevel;
      //this.scoreList = map.scoreMap;
    });
    //详情界面的成绩
    FrameRequest.requestArray("by/byApply/getscorelistForQuery.htm", {id: obj.id}, (arrary)=>{
      this.scoreList = arrary;
    });
  }

  //查看审核记录
  showAuthListWin(applyId) {
    this.editShowType="authQuery";
    //详情
    FrameRequest.requestMap(this.AUTH_DETAIL_URL, {id: applyId}, (map) => {
      this.item = map.detail;
      this.authList = map.authList;
    });
    //详情界面的成绩
    /*FrameRequest.requestArray("by/byApply/getscorelist.htm", {id: applyId}, (arrary)=>{
      this.authList = arrary;
    });*/
    
  }

  //审核
  doAudit() {
    if (!FrameFunction.validForm(this.formModel)) {
      return;
    }
    this.item.auth_type = this.radioSelect;
    if (this.item.auth_type == 0) {//审核通过
      this.item.status = this.applyStatus.TO_FINAL_AUDIT_2;//待终审
      this.item.is_auth_back = 0;
    } else if (this.item.auth_type == 1) {
      this.item.status = this.applyStatus.NEW_0;
      this.item.is_auth_back = 1;//标识驳回
    }
    //先做学历认证
    FrameRequest.requestEntity("by/byApply/educertified.htm", this.item, (entity)=>{
      if (entity == 1) {
        AppComponent.alert({title:"信息提示",text:"该考生没有前置学历认证，请现场确认!"});
      }
      FrameRequest.request("by/byApply/audit.htm", this.item, (ret)=>{
        if (ret.errorCode == 0) {
          this.hideModal();
          this.framePager.reload();
          AppComponent.GobalComponent.successMsg("审核成功");
        }
      });
    });
  }


  callBackApplyForStd() {
    let checkedArray = this.framePager.getCheckedArray();
      if (checkedArray.length == 0 || checkedArray.length>1) {
        AppComponent.alert({title:"信息提示",text:"请选择一条记录!"});
        return;
      }
      if (checkedArray[0].status != this.applyStatus.TO_FIRST_AUDIT_1) {
          AppComponent.alert({title:"信息提示",text:"申请单状态不是待现场确认，不允许操作!"});
          return;
      }
      
    
    AppComponent.confirm("确定驳回给考生吗?",()=>{

    AppComponent.GobalComponent.setLoading(true);
    FrameRequest.request("by/byApply/callBackForStd.htm", {id: checkedArray[0].id,std_source:checkedArray[0].std_source}, (ret)=>{
      AppComponent.GobalComponent.setLoading(false);
      this.hideModal();
      this.framePager.reload();
      if (ret.errorCode == 1) {
       
        AppComponent.GobalComponent.successMsg("驳回给考生成功!");
      }else{
        
        AppComponent.GobalComponent.errorMsg(ret.errorMsg);
      }
    });
  });
  }


  //笔记卡审核
  doAuditWrite() {

  }

  formateOrignScore(item) {
    if (item.score_source == '顶替' || item.origin_score == '888') {
      return '顶替';
    } else if (item.score_source == '免考' || item.origin_score == '999') {
      return '免考';
    }
    if (item.origin_score == '-9') {
      return '缺考';
    } else if (item.origin_score == '-3') {
      return '违纪';
    } else if (item.origin_score == '-2') {
      return '免考';
    } else if (item.origin_score == '-1') {
      return '舞弊';
    }
    return item.origin_score;
  }

  formateFinalScore(item) {
    if (item.score_source == '顶替' || item.final_score == '888') {
      return '顶替';
    } else if (item.score_source == '免考' || item.final_score == '999') {
      return '免考';
    }
    if (item.final_score == '-9') {
      return '缺考';
    } else if (item.final_score == '-3') {
      return '违纪';
    } else if (item.final_score == '-2') {
      return '免考';
    } else if (item.final_score == '-1') {
      return '舞弊';
    }
    return item.final_score;
  }

  //下载毕业登记表
  getRegisterPdf() {
    let checkedArray = this.framePager.getCheckedArray();
    if (checkedArray.length == 0) {
      AppComponent.alert({title:"信息提示",text:"请选择考生毕业申请!"});
      return;
    }
    FrameRequest.download("by/byApply/getregisterpdf.htm", {applyId: checkedArray[0].id});
  }

  //下载毕业登记表
  getRegisterPdfForBatch() {
    
    let checkedArray = this.framePager.getCheckedArray((item)=>item.id);
    if (checkedArray.length == 0) {
      AppComponent.alert({title:"信息提示",text:"请选择考生毕业申请!"});
      return;
    }
   
    AppComponent.confirmForTitle("温馨提醒","毕业登记表优先选择网页打印，用软件打开打印必须选择实际大小再打印",()=>{
      AppComponent.GobalComponent.setLoading(true);
      FrameRequest.download("by/byApply/getByApplyRegisterPdfForBatch.htm",  {applyIds: checkedArray.join()}, ()=>{
          AppComponent.GobalComponent.setLoading(false);
          AppComponent.GobalComponent.successMsg("下载成功!");
      });
    });


  }

  //显示手工录入分数
  showInputDialog(templateModal, courseId) {
    this.inputScore.old_course_id = courseId;
    this.inputModalWin = this.bsModalService.show(templateModal, { class: "modal-lg" });
  }

  //课程顶替界面
  showReplDialog(templateModal, id_arg, courseId_arg) {
    this.repl_score_id = !id_arg ? "" : id_arg;
    this.repl_course_id = courseId_arg;
    this.courseReplWin = this.bsModalService.show(templateModal, { class: "modal-lg" });
    //查询
    let params = {
      stdRegId: this.item.std_id,
      majorId: this.item.major_id,
      courseId: courseId_arg
    }
    FrameRequest.requestArray("kj/byCourseReplRecord/byReplscoreList.htm", params, (arrary)=>{
      this.replScoreList = arrary;
    });
  }

  //转入成绩关联
  showTurnInDialog(templateModal, courseId) {
    this.turnInQuery.oldCourseId = courseId;
    this.inputScore.old_course_id = courseId;
    this.turnInAssocitWin = this.bsModalService.show(templateModal, { class: "modal-lg" });
  }

  //老生成绩
  showOldCjDialog(templateModal) {
    this.oldCjWin = this.bsModalService.show(templateModal, { class: "modal-lg" });
  }

  //关联准考证
  showTicketAssocitDialog(templateModal) {
    this.ticketNoAssocitWin = this.bsModalService.show(templateModal, { class: "modal-lg" });
    this.stdTicketRefList = [];
    this.ticketAssoQuery.ticketNo = "";
    this.ticketRadioItem = {};
    this.assoStdSelected = undefined;
    FrameRequest.requestArray("by/stdRegInfo/showassolist.htm", {by_apply_id: this.item.id}, (arr) => {
      if (arr.length > 0) {
        for (let std of arr) {
          std.assoStatus="已关联";
          this.stdTicketRefList.push(std);
        }
      }
    });
  }

  //手工录入分数
  saveMannualInput() {
    if (!FrameFunction.validForm(this.scoreFormModel)) {
      return;
    }
    if (Number(this.inputScore.final_score) < 60) {
      AppComponent.GobalComponent.successMsg('信息保存成功!');
      return;
    }
    this.inputScore.by_apply_id = this.item.id;
    this.inputScore.std_reg_id = this.item.std_id;
    this.inputScore.major_id = this.item.major_id;
    this.inputScore.score_source = "4";//手工录入
    //更新列表成绩
    for (let score of this.scoreList) {
      if (score.course_id == this.inputScore.old_course_id) {
        score.score_source = this.inputScore.score_source
        score.score_nature = this.inputScore.score_nature
        score.course_code == this.inputScore.course_code;
        score.course_name == this.inputScore.course_name;
        score.origin_score = this.inputScore.final_score;
        score.final_score = this.inputScore.final_score;
        
        score.is_passed = Number.parseInt(this.inputScore.final_score) >= 60 ? "1" : "0";
        break;
      }
    }
    //保存
    this.inputScore.use_type = "1";
    let addUrl = "kj/kjByInputScore/add.htm";
    FrameRequest.requestEntity(addUrl, this.inputScore, async () => {
      AppComponent.GobalComponent.successMsg('信息保存成功!');
      this.inputModalWin.hide();
      this.radioItem = {};//清空radio选择
    });
  }
  
  //上传毕业照片
  uploadByPhoto(applyId) {
    let param = {
      byApplyId: applyId,
      RequestLoading: true
    };
    this.uploader.choooseFileAndUpload(param, ((ret) => {
      if (ret.errorCode > 0) {
        AppComponent.alert({title:"信息提示", text: ret.errorMsg});
      } else if (ret.errorCode == -1) {
        AppComponent.GobalComponent.successMsg("上传失败!");
      } else if (ret.errorCode == 0) {
        AppComponent.GobalComponent.successMsg("上传成功!");
        this.item.by_photo = ret.map.file_path;
      }
    }));
  }

  replRadioItem: any;
  replRadioCheckFun(it) {
    this.replRadioItem = it;
  }

  //保存顶替
  replSave() {
    
    if (!this.replRadioItem) {
      AppComponent.alert({title:"信息提示",text:"请选择顶替成绩!"});
      return;
    }
    let parm = {
      by_apply_id: this.item.id,      //毕业Id
      std_reg_id: this.item.std_id,
      major_id: this.item.major_id,
      repl_score_ids: this.repl_score_id,       //未通过的成绩ID
      repl_course_ids: this.repl_course_id,    //未考或不及格课程----待顶替
      new_score_ids: this.replRadioItem.id,    //新成绩IDs
      detail_id: this.replRadioItem.detail_id  //规则详情ID
    }
    FrameRequest.request("by/byCourseReplRecord/repl.htm", parm, (ret)=>{
      
      if (ret.errorCode == 0) {
        this.courseReplWin.hide();

        this.repl_score_id = "";//清空
        this.repl_course_id = "";
        this.replRadioItem = undefined;

        //刷新成绩显示
        FrameRequest.requestArray("by/byApply/getscorelist.htm", {id: this.item.id}, (arrary) => {
          this.scoreList = arrary;
        });
        AppComponent.GobalComponent.successMsg("顶替成功!");
      }
    });
  }

  //老生成绩选择
  selectOldCj() {
    let checkedArray = this.oldCjPager.getCheckedArray();
    if (checkedArray.length == 0) {
      AppComponent.alert({title:"信息提示",text:"请选择老成绩!"});
      return;
    }
    if (checkedArray.length > 1) {
      AppComponent.alert({title:"信息提示",text:"只能选择一条老成绩!"});
      return;
    }
    let scoreShow = {};
    scoreShow["course_code"] = checkedArray[0].kechengdaihao;
    scoreShow["course_name"] = "";
    scoreShow["score_source"] = "老成绩引入";
    //scoreShow["score_nature"] = "老课程成绩";
    scoreShow["origin_score"] = checkedArray[0].chengji;
    scoreShow["final_score"] = checkedArray[0].chengji;
    scoreShow["is_passed"] = Number.parseInt(checkedArray[0].chengji) >= 60 ? "1" : "0";
    this.scoreList.push(scoreShow);
    //保存到库
    this.inputScore.by_apply_id = this.item.id;
    this.inputScore.std_reg_id = this.item.std_id;
    this.inputScore.major_id = this.item.major_id;
    this.inputScore.course_code = checkedArray[0].kechengdaihao;
    this.inputScore.major_code = checkedArray[0].zhuanyedaihao;
    this.inputScore.origin_score = checkedArray[0].chengji;
    this.inputScore.final_score = checkedArray[0].chengji;
    //this.inputScore.score_nature = "1";//老课程成绩
    this.inputScore.score_source = "14";//老成绩引入
    let addUrl = "kj/kjByInputScore/add.htm";
    FrameRequest.requestEntity(addUrl, this.inputScore, async () => {
      AppComponent.GobalComponent.successMsg('选择成功!');
      this.oldCjWin.hide();
      this.radioItem = {};//清空radio选择
    });
  }

  //删除毕业申请验证----只能删除0、1状态的
  deleteApply(item){
    if (item.status > 1) {
      AppComponent.alert({title:"信息提示",text:"只能删除新建状态申请!"});
      return;
    }
    AppComponent.confirm("确定删除吗?",()=>{
      FrameRequest.requestMap(this.DELETE_URL, {ids:item.id}, () => {
        AppComponent.GobalComponent.successMsg('删除成功!');
         this.framePager.reload();
      });
    });
  }

  //******************************************新建毕业申请*********************************************** */
  stdRefList = [];//引用考生列表
  stdTicketRefList = [];//准考证引用考生列表
  radioItem = {};
  ticketRadioItem = {};
  byMajorList = [];//毕业带选择专业
  showStdRefDialog(templateModal) {
    this.stdRefWin = this.bsModalService.show(templateModal, { class: "modal-lg" });
  }
  //引用考生-查询
  findStdRefList() {
    if (!this.stdRefQuery.certNo && !this.stdRefQuery.ticketNo) {
      AppComponent.alert({title:"信息提示",text:"请输入过滤条件!"});
      return;
    }
    //刷新成绩显示
    let param = {
      cert_no: this.stdRefQuery.certNo, 
      ticket_no: this.stdRefQuery.ticketNo,
      std_source: "" //3-助学班考生
    };
    FrameRequest.requestArray("std/stdRegInfo/list.htm", param, (arrary) => {
        if (arrary.length > 0 && arrary[0].std_source != 3) {
          AppComponent.alert({title:"信息提示",text:"社会考生请到市考办申请!"});
          return;
        } else {
          this.stdRefList = arrary;
        }
    });
  }

  //选择的考生 查询待毕业专业
  stdRefRadioCheckFun(item) {
    this.stdRefQuery.masterSchoolId = item.school_id;
    /*FrameRequest.requestArray("std/stdMajor/findstdmajors.htm", {std_reg_id: item.id}, (arrary) => {
      this.byMajorList = arrary;
    });*/
  }

  //新申请
  selectStdRef() {
    if (!this.stdRefList.length || !this.radioItem['id']) {
      AppComponent.alert({title:"信息提示",text:"请选择考生!"});
      return;
    }
    if (!this.stdRefQuery.majorId) {
      AppComponent.alert({title:"信息提示",text:"请选择专业!"});
      return;
    }
    let param = {
      std_reg_id: this.radioItem['id'], 
      major_id: this.stdRefQuery.majorId,
      school_id: this.stdRefQuery.masterSchoolId
    };
    FrameRequest.requestEntity("by/byApply/createbymgm.htm", param, async () => {
      AppComponent.GobalComponent.successMsg('选择成功!');
      this.framePager.reload();
      this.stdRefWin.hide();
    });
  }

//******************************关联准考证选择************************** */
assoStdSelected : any;
findStdTicketRefList() {
  if (!this.ticketAssoQuery.ticketNo) {
    AppComponent.alert({title:"信息提示",text:"请输入过滤条件!"});
    return;
  }
  //刷新成绩显示
  let param = {
    ticket_no: this.ticketAssoQuery.ticketNo
  };
  FrameRequest.requestArray("std/stdRegInfo/list.htm", param, (arrary) => {
    this.stdTicketRefList = arrary;
    FrameRequest.requestArray("by/stdRegInfo/showassolist.htm", param, (arr) => {
      for (let std of this.stdTicketRefList) {
        std.assoStatus="";
      }
      if (arr.length > 0) {
        for (let std of arr) {
          std.assoStatus="已关联";
          this.stdTicketRefList.push(arr);
        }
      }
    });
  });
  this.assoStdSelected = undefined;
}

//关联准考证--选择的考生 查询指定准考证成绩
stdTicketCheckFun(item) {
  this.showTicketPage = true;
  this.ticketAssoQuery.ticketNo = item.ticket_no;
  this.assoStdSelected = item;
  this.ticketAssoPager.reload();
}
//关联准考证操作
selectTicketNoAssocit() {
  if (!this.assoStdSelected || !this.ticketRadioItem) {
    AppComponent.alert({title:"信息提示",text:"请选择!"});
    return;
  }
  if (this.assoStdSelected.assoStatus == '已关联') {
    AppComponent.alert({title:"信息提示",text:"不能重复关联!"});
    return;
  }
  AppComponent.confirm("确定关联准考证成绩?",()=>{
      //加到列表显示
      let param = {
        stdRegId: this.item.std_id,
        byApplyId: this.item.id,
        refTicketNo: this.assoStdSelected.ticket_no
      };
      let addUrl = "kj/kjByInputScore/refticketscore.htm";
      FrameRequest.requestEntity(addUrl, param, async () => {
        AppComponent.GobalComponent.successMsg('关联成功!');
        this.closeAssoTicketWin();
        //刷新成绩显示
        FrameRequest.requestArray("by/byApply/getscorelist.htm", {id: this.item.id}, (arrary) => {
          this.scoreList = arrary;
        });
      });
  });
}
//取消关联
unSelectTicketNoAssocit() {
  
  if (!this.assoStdSelected) {
    AppComponent.alert({title:"信息提示",text:"请选择!"});
    return;
  }
  if (this.assoStdSelected.assoStatus == '') {
    AppComponent.alert({title:"信息提示",text:"只能取消已关联的准考证!"});
    return;
  }
  AppComponent.confirm("确定取消关联准考证成绩?",()=>{
    let param = {
      byApplyId: this.item.id,
      refTicketNo: this.assoStdSelected.ticket_no
    };
    let addUrl = "kj/kjByInputScore/delticketscore.htm";
    FrameRequest.requestEntity(addUrl, param, async () => {
      AppComponent.GobalComponent.successMsg('取消成功!');
      this.closeAssoTicketWin();
      //刷新成绩显示
      FrameRequest.requestArray("by/byApply/getscorelist.htm", {id: this.item.id}, (arrary) => {
        this.scoreList = arrary;
      });
    });
  });
}
//关闭关联准考证界面
closeAssoTicketWin() {
  this.ticketNoAssocitWin.hide();
  this.showTicketPage = false;
  this.stdTicketRefList=[];
  this.assoStdSelected = undefined;
}

//****************************************外省转入成绩****************************************************** */
  turnInQueryRequest() {
    if (!this.turnInQuery.stdName && !this.turnInQuery.ticketNo) {
      AppComponent.alert({title:"信息提示",text:"请输入过考生姓名或准考证号!"});
      return;
    }
    //刷新成绩显示
    let param = {
      std_name : this.turnInQuery.stdName,
      ticket_no : this.turnInQuery.ticketNo,
      course_code : this.turnInQuery.courseCode
    }
    FrameRequest.requestArray("by/byApply/getturninscorelist.htm", param, (arrary) => {
      this.turnInScoreList = arrary;
    });
    this.radioItem = {};//清空radio选择
  }

  //转入选择
  turnInSelect(it) {
    
    this.turnInScore = it;
  }

  //选择转入成绩替换
  selectTurnInScore() {
    if (!this.turnInScoreList.length || !this.radioItem['id']) {
      AppComponent.alert({title:"信息提示",text:"请选择转入成绩!"});
      return;
    }
    //保存到手工处理成绩表
    //保存到库
    this.inputScore.by_apply_id = this.item.id;
    this.inputScore.std_reg_id = this.item.std_id;
    this.inputScore.major_id = this.item.major_id;
    this.inputScore.course_code = this.turnInScore.course_code;
    this.inputScore.course_name = this.turnInScore.course_name;
    this.inputScore.origin_score = this.turnInScore.final_score;
    this.inputScore.final_score = this.turnInScore.final_score;
    this.inputScore.use_type = "1";//更新匹配老课程的成绩
    this.inputScore.score_source = "13";//手工---转考转入成绩
    let addUrl = "kj/kjByInputScore/add.htm";
    FrameRequest.requestEntity(addUrl, this.inputScore, async () => {
      AppComponent.GobalComponent.successMsg('转入成功!');
      this.turnInAssocitWin.hide();
      this.radioItem = {};//清空radio选择
      //刷新成绩显示
      FrameRequest.requestArray("by/byApply/getscorelist.htm", {id: this.item.id}, (arrary) => {
        this.scoreList = arrary;
      });
    });
  }

  resetdata(){
    this.query.query="";
    this.query.masterSchoolId="";
    this.query.jionSchoolId="";
    this.query.cityOrgId="";
    this.query.majorId="";
    this.query.examTimeId="";
    this.query.std_source="";
    this.query.status="";
    
    
  }

  downApplyXls() {
    let param = {
      
      exam_time_id: this.query.examTimeId,
      by_status: this.query.status,
      major_id: this.query.majorId,
      school_id: this.query.masterSchoolId,
      jion_school_id: this.query.jionSchoolId,
      city_org_id: this.query.cityOrgId,
      std_source: this.query.std_source
    };
    AppComponent.GobalComponent.setLoading(true);
    FrameRequest.download("by/byApply/downapplyxls.htm", param, ()=>{
        AppComponent.GobalComponent.setLoading(false);
        AppComponent.GobalComponent.successMsg("导出成功!");
    });
  }

}