
import { FormBuilder, Validators } from '@angular/forms';
import { CustomValidators } from 'ng2-validation';
import { BsModalService } from "ngx-bootstrap/modal";

import * as _ from 'lodash';
import { FlexTableComponent } from '../../../../shared/common/FlexTable.component';
import { OnInit, Component } from '@angular/core';

import { FrameRequest } from '../../../../shared/frame/frame-request';
import { AppComponent } from '../../../..';

//审批状态
const APPLY_STATUS = {
    NEW: 0,//草稿
    LOCAL_VERIFY: 1,//待现场验证
    PROV_VERIFY:2,//待省级验证
    ARCHIVE:3//归档
};

@Component({
    selector: 'cert_edu_apply_managel',
    templateUrl: './cert_edu_apply.component.manage.html',
    styleUrls: ['./cert_edu_apply.component.manage.scss']
})
export class CertEduApplyComponentManage extends FlexTableComponent implements OnInit {

    public query = {
        "ticket_no": "",
        "std_name": "",
        "std_cert_no": "",
        "cert_type_id": "",
        "time_config_id": "",
        "is_atg":""
    };

    QUERY_URL = "mk/mkCertEduApply/page.htm";
    DELETE_URL = "mk/mkCertEduApply/delete.htm";
    GET_URL = "mk/mkCertEduApply/get.htm";
    ADD_URL = "mk/mkCertEduApply/add.htm";
    EDIT_URL = "mk/mkCertEduApply/edit.htm";

    APPLY_VERIFY_URL = "mk/mkCertEduApply/verify.htm";
    CERT_TYPE_List_URL= "mk/mkCertType/listAll.htm";
    VERIFY_ALL_URL= "mk/mkCertEduApply/verifyAll.htm";

    SYNC_ALL_URL= "mk/mkCertEduApply/syncScores.htm";

    bsModalWin_verify : any;
    certTypeList = [];

    constructor(
        public bsModalService: BsModalService,
        fb: FormBuilder
    ) {
        super();

        FrameRequest.requestArray(this.CERT_TYPE_List_URL, {type: 1}, (array) => {
            this.certTypeList = array;
          });
    
    }

    search(param) {
        let searchCondition = this.query;
        //参数合并
        _.assignIn(param, searchCondition);
    }

    goVerify(tpl){
        let checkedArray =  this.framePager.getCheckedArray();
        if(checkedArray.length == 0){
            AppComponent.alert({title:"信息提示",text:"请选择数据!"});
            return;
        }
        if(checkedArray.length > 1){
            AppComponent.alert({title:"信息提示",text:"只允许操作一条数据!"});
            return;
        }

        FrameRequest.requestEntity(this.GET_URL, {id: checkedArray[0].id}, (entity) => {
            this.item = entity;
            this.editShowType = 'only';
            // this.shouModalWin_verify(tpl);
            
         });
    }

    async shouModalWin_verify(editFormTemplateModal, modalcss?) {
        if(!this.item) this.item = {};
        let css = modalcss ? modalcss : "modal-lg";//big_modal modal-lg
        this.bsModalWin= this.bsModalService.show(editFormTemplateModal, { class: css });
    }

    //现场审批
    saveVerify(){
        if(!(this.item.status+"")){
            AppComponent.alert({title:"信息提示",text:"请填写审批状态!"});
            return
        }
        if(!this.item.verify1_remark || this.item.verify1_remark.lengh == 0){
            AppComponent.alert({title:"信息提示",text:"请填写审批意见!"});
            return
        }
        let verfiyStatus;
        switch (this.item.status) {
            case "0":
                verfiyStatus = APPLY_STATUS.NEW
                break;
            case "1":
                verfiyStatus = APPLY_STATUS.PROV_VERIFY
                break;
            default:
                break;
        }
        FrameRequest.requestMap(this.APPLY_VERIFY_URL, 
            { apply_id: this.item.id, status: verfiyStatus,verify1_remark:this.item.verify1_remark}, (map) => {
                AppComponent.alert({title:"信息提示",text:"审批提交成功!"});
                this.hideModal();
               this.framePager.reload();
         });
    }

    doVerifyAll(){
       let repParam =  _.cloneDeep(this.query);
        repParam['status'] = APPLY_STATUS.PROV_VERIFY;
        FrameRequest.requestMap(this.VERIFY_ALL_URL, 
            repParam, (map) => {
                AppComponent.alert({title:"信息提示",text:"全部审批通过提交成功!"});
                this.hideModal();
               this.framePager.reload();
         });

    }

    syncScores(){
        FrameRequest.requestEntity(this.SYNC_ALL_URL, {}, (entity) => {
            AppComponent.alert({title:"信息提示",text:"同步成绩成功!"});
        })
    }

    downloadTemplate() {
        FrameRequest.download('/std/stdRegInfo/downloadTpl.htm', {fileName: 'mk_apply.doc'});
    }
  
    downApplyPDF(){
        let checkArray = this.framePager.getCheckedArray();
  
        if(checkArray.length != 1){
          AppComponent.alert({title:"信息提示",text:"请单选一条申请数据!"});
          return
        }
        FrameRequest.download('mk/mkCertEduApply/downApplyPDF.htm', {std_id:checkArray[0].std_reg_id,time_config_id:checkArray[0].time_config_id});
      }

    isPakage(path){
        if(path.indexOf('zip') != -1 || path.indexOf('rar') != -1){
            return true;
        }
        return false;
    }
}


