
import { FormBuilder, Validators } from '@angular/forms';
import { CustomValidators } from 'ng2-validation';
import { BsModalService } from "ngx-bootstrap/modal";

import * as _ from 'lodash';
import { FlexTableComponent } from '../../../../shared/common/FlexTable.component';
import { OnInit, Component } from '@angular/core';

import { FrameRequest } from '../../../../shared/frame/frame-request';
import { AppComponent } from '../../../..';

//审批状态
const APPLY_STATUS = {
    NEW: 0,//草稿
    LOCAL_VERIFY: 1,//待现场验证
    PROV_VERIFY:2,//待省级验证
    ARCHIVE:3//归档
};

@Component({
    selector: 'cert_nedu_apply_manage',
    templateUrl: './cert_nedu_apply.component.manage.html',
    styleUrls: ['./cert_nedu_apply.component.manage.scss']
})
export class CertNeduApplyComponentManage extends FlexTableComponent implements OnInit {

    public query = {
        "std_name": "",
        "std_cert_no": "",
        "cert_type_id": "",
        "time_config_id": "",
        "is_atg":""
    };

    QUERY_URL = "mk/mkCertNeduApply/page.htm";
    DELETE_URL = "mk/mkCertNeduApply/delete.htm";
    GET_URL = "mk/mkCertNeduApply/get.htm";
    ADD_URL = "mk/mkCertNeduApply/add.htm";
    EDIT_URL = "mk/mkCertNeduApply/edit.htm";

    CERT_TYPE_List_URL= "mk/mkCertType/listAll.htm";
    CERT_TYPE_COURSE_URL= "mk/mkCertNeduApply/getCourse.htm"
    APPLY_VERIFY_URL = "mk/mkCertNeduApply/verify.htm";

    SYNC_ALL_URL = "mk/mkCertNeduApply/syncScores.htm";

    certTypeList = null;
    courseList = null;

    bsModalWin_verify : any;

    constructor(
        public bsModalService: BsModalService,
        fb: FormBuilder
    ) {
        super();
        // CustomValidators.rangeLength([1, 6])
        this.formModel = fb.group({
            id: [null],
            'std_name': [null],
            'std_cert_no': [null],
            'cert_no': [null],
            'cert_type_id': [null],
            'status': [null],
            'exam_date': [null],
            'file_path': [null],
            'verify_remark2': [null],
            'verify_remark3': [null],
            'verify_remark1': [null],
        });

        FrameRequest.requestArray(this.CERT_TYPE_List_URL, {}, (array) => {
            this.certTypeList = array;
          });

    }

    search(param) {
        let searchCondition = this.query;
        //参数合并
        _.assignIn(param, searchCondition);
    }


    goVerify(tpl){
        let checkedArray =  this.framePager.getCheckedArray();
        if(checkedArray.length == 0){
            AppComponent.alert({title:"信息提示",text:"请选择数据!"});
            return;
        }

        FrameRequest.requestMap(this.CERT_TYPE_COURSE_URL, {cert_type_id: checkedArray[0].id}, (map) => {
            this.item = map['apply'];
            this.courseList = map['courseList'];

            this.shouModalWin_verify(tpl);
            
         });
    }

    async shouModalWin_verify(editFormTemplateModal, modalcss?) {
        if(!this.item) this.item = {};
        let css = modalcss ? modalcss : "modal-lg";
        this.bsModalWin= this.bsModalService.show(editFormTemplateModal, { class: css });
    }

    //现场审批
    saveVerify(){
        if(!(this.item.status+"")){
            AppComponent.alert({title:"信息提示",text:"请填写审批状态!"});
            return
        }
        if(!this.item.verify_remark1 || this.item.verify_remark1.lengh == 0){
            AppComponent.alert({title:"信息提示",text:"请填写审批意见!"});
            return
        }
        let verfiyStatus;
        switch (this.item.status) {
            case 0:
                verfiyStatus = APPLY_STATUS.NEW
                break;
            case 1:
                verfiyStatus = APPLY_STATUS.PROV_VERIFY
                break;
            default:
                break;
        }
        FrameRequest.requestMap(this.APPLY_VERIFY_URL, 
            { apply_id: this.item.id, status: APPLY_STATUS.PROV_VERIFY,verify_remark1:this.item.verify_remark1}, (map) => {
                AppComponent.alert({title:"信息提示",text:"审批提交成功!"});
                this.hideModal();
               this.framePager.reload();
         });
    }

    syncScores(){
        FrameRequest.requestEntity(this.SYNC_ALL_URL, {}, (entity) => {
            AppComponent.alert({title:"信息提示",text:"同步成绩成功!"});
        })
    }

    downloadTemplate() {
        FrameRequest.download('/std/stdRegInfo/downloadTpl.htm', {fileName: 'mk_apply.doc'});
    }

    downApplyPDF(){
        let checkArray = this.framePager.getCheckedArray();
  
        if(checkArray.length != 1){
          AppComponent.alert({title:"信息提示",text:"请单选一条申请数据!"});
          return
        }
        FrameRequest.download('mk/mkCertEduApply/downApplyPDF.htm', {std_id:checkArray[0].std_reg_id,time_config_id:checkArray[0].time_config_id});
      }

}


