import { Component, OnInit, Input, ViewChild, Output, EventEmitter } from "@angular/core";
import { FlexTableComponent } from "../../../../shared/common/FlexTable.component";
import { FormBuilder, Validators } from '@angular/forms';
import { CustomValidators } from 'ng2-validation';
import { BsModalService } from "ngx-bootstrap/modal";
import { FramePagerComponent } from "../../../../core/pager/pager.component";
import { FrameRequest } from "../../../../shared/frame/frame-request";
import * as _ from 'lodash';
import { AppComponent } from "../../../..";

@Component({
  selector: "std-layout-query",
  templateUrl: "./std-layout-query.component.html",
  styleUrls: ["./std-layout-query.component.scss"]
})
export class StdLayoutQueryComponent extends FlexTableComponent implements OnInit {
  public query = {
    "year_code": "",
    "ticket_no": "",
    "course_id": "",
    "enrol_agent_id": "",
    "exam_batch": "",
    "status": "",
    "exam_time_id":"",
    "special_flag":"",
    "enrol_type" : "",
    "cert_no":"",
    "exam_unit_id":"",
    "room_code":""
  };

  QUERY_URL = "std/stdEnrol/pageStdLayout.htm";
  DELETE_URL = "std/stdEnrol/delete.htm";
  GET_URL = "std/stdEnrol/get.htm";
  ADD_URL = "std/stdEnrol/add.htm";
  EDIT_URL = "std/stdEnrol/edit.htm";
  COURSE_LIST_URL = "pl/plCourse/listCourseByExamTimeId.htm";
  AREA_LIST_URL = "cf/cfOrganization/list.htm?org_type=4&status=1"; //考区列表
  GET_TYPE_URL = "frame/optr/getDeptType.htm"; //获取登录用户的机构类型
  EXPORT_URL = "std/stdEnrol/layoutExport.htm";

  examAgentArray = [];
  courseList = [];
  examUnitList = [];
  flag: boolean = true;



  constructor(
    public bsModalService: BsModalService,
    fb: FormBuilder
  ) {
    super();
  }

  ngOnInit() {
    FrameRequest.requestEntity("pl/plExamTime/getCurrentExamTimeId.htm", {}, (entity) => {
      if(entity) {
        this.query.exam_time_id = entity.id;
        //this.framePager.reload();
      }

      FrameRequest.requestArray(this.COURSE_LIST_URL,{exam_time_id:this.query.exam_time_id}, async (array) => {
        this.courseList = array;
      });
      
    });

    FrameRequest.requestArray(this.AREA_LIST_URL,{}, async (array) => {
      this.examAgentArray = array;
    });
   
    FrameRequest.requestEntity(this.GET_TYPE_URL, {}, (entity) => {
      if(entity == 0) {
        this.flag = false;
      } else {
        this.flag = true;
      }
    });

  }

  search(param){
    

    let searchCondition = this.query;
    //参数合并
    _.assignIn(param,searchCondition);
    for (const key in param) {
      if (param.hasOwnProperty(key)) {
        const element = param[key];
        if(element == null) param[key] = "";
        
      }
    }
  }


  freshExamUit() {
    if (!this.query.exam_time_id || !this.query.enrol_agent_id) {
        return;
    }

    var param = {
        exam_time_id: this.query.exam_time_id,
        org_id: this.query.enrol_agent_id,
    }

    FrameRequest.requestArray("kw/kwExamUnit/findAuthExamUitList.htm",param, async (array) => {
      this.examUnitList = array;
    });
  }

  export() {
    if(!this.query.exam_time_id){
      AppComponent.alert({title:"信息提示",text:"请选择考期!"});
      return;
    }

    if(!this.query.enrol_agent_id){
      this.query.enrol_agent_id='';
    }

    if(!this.query.course_id){
      this.query.course_id='';
    }

    if(!this.query.exam_unit_id){
      this.query.exam_unit_id='';
    }
    


    AppComponent.GobalComponent.setLoading(true);
    FrameRequest.download(this.EXPORT_URL, this.query, () => {
      AppComponent.GobalComponent.setLoading(false);
      AppComponent.GobalComponent.successMsg("导出成功");
    });
  }

 
  //下载准考证
  downTicket(item) {
    
	
	FrameRequest.requestMap("std/stdRegInfo/downTicketTime.htm",{exam_time_id:item.exam_time_id},(map)=>{
		if (map['inTime']) {
			FrameRequest.requestEntity("std/stdRegInfo/queryStdByTicketNo.htm",{ticket_no: item.ticket_no},  (entity) => {
				
				if(entity) {
				  AppComponent.GobalComponent.setLoading(true);
				  FrameRequest.download("std/stdRegInfo/downTicket.htm",  {ticket_no: item.ticket_no,exam_time_id:item.exam_time_id}, ()=>{
					  AppComponent.GobalComponent.setLoading(false);
					  AppComponent.GobalComponent.successMsg("下载成功!");
				  });
		  
				}else{
				  AppComponent.alert({ 'title': '提示', 'text': '准考证'+item.ticket_no+'在系统中不存在!' });
				}
				
			  })
		}else{
			if (map['time']) {
				AppComponent.GobalComponent.errorMsg("准考证在下载时间："+map['time'].start_time+" 到"+ map['time'].end_time);
			} else {
				AppComponent.GobalComponent.errorMsg("不在下载时间内,暂不允许下载");
			}
			
		}
	});
   
    
    }

}
